import Serverless from "serverless";
import { BaseService } from "./baseService";
/**
 * Defines the Azure Key Vault configuration
 */
export interface AzureKeyVaultConfig {
    /** The name of the azure key vault */
    name: string;
    /** The name of the azure resource group with the key vault */
    resourceGroup: string;
}
/**
 * Services for the Key Vault Plugin
 */
export declare class AzureKeyVaultService extends BaseService {
    private funcApp;
    /**
     * Initialize key vault service and get function app
     * @param serverless Serverless object
     * @param options Serverless CLI options
     */
    constructor(serverless: Serverless, options: Serverless.Options);
    /**
     * Sets the KeyVault policy for the function app to allow secrets permissions.
     * @param keyVaultConfig Azure Key Vault settings
     */
    setPolicy(keyVaultConfig: AzureKeyVaultConfig): Promise<import("@azure/arm-keyvault/esm/models").VaultsCreateOrUpdateResponse>;
}
